@@ -14,8 +14,8 @@ default_stat_labels <- function() {
     sd = "SD",
     var = "Variance",
     median = "Median",
-    p25 = "25th Percentile",
-    p75 = "75th Percentile",
+    p25 = "Q1",
+    p75 = "Q3",
     min = "Min",
     max = "Max",
     n = "n",
