@@ -7,3 +7,10 @@ test_that("ard_attributes() works", {
       as.data.frame()
   })
 })
+
+test_that("ard_attributes() errors when there is no dataframe", {
+  expect_error(
+    ard_attributes("test"),
+    "There is no method for objects of class <character>."
+  )
+})
